Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(198)

Unified Diff: pkg/analysis_server/lib/src/services/completion/local_computer.dart

Issue 1060713005: rename completion computer to contributor (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: merge Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/completion/local_computer.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/local_computer.dart b/pkg/analysis_server/lib/src/services/completion/local_computer.dart
index b838f37e57596972fe6ffe5309203681761b941a..f547a746f8dd6dd0919eb31d49e664b9349d7ac0 100644
--- a/pkg/analysis_server/lib/src/services/completion/local_computer.dart
+++ b/pkg/analysis_server/lib/src/services/completion/local_computer.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library services.completion.computer.dart.local;
+library services.completion.contributor.dart.local;
import 'dart:async';
@@ -77,10 +77,10 @@ String _nameForType(TypeName type) {
}
/**
* A computer for calculating `completion.getSuggestions` request results
* for the local library in which the completion is requested.
*/
-class LocalComputer extends DartCompletionComputer {
+class LocalReferenceContributor extends DartCompletionContributor {
@override
bool computeFast(DartCompletionRequest request) {
OpType optype = request.optype;
@@ -77,10 +77,10 @@ String _nameForType(TypeName type) {
}
/**
- * A computer for calculating `completion.getSuggestions` request results
+ * A contributor for calculating `completion.getSuggestions` request results
* for the local library in which the completion is requested.
*/

Powered by Google App Engine
This is Rietveld 408576698